==> jc-1.4.0.tar.gz: java/lang/VMCompiler.h <==
// final class java.lang.VMCompiler

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 1ec1b2c5fdf4b5df java_lang_VMCompiler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMCompiler_H_
#define _JC_java_lang_VMCompiler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VMCompiler$sub_refs	_jc_java_lang_VMCompiler$sub_refs;
typedef struct _jc_java_lang_VMCompiler$sub_nonrefs	_jc_java_lang_VMCompiler$sub_nonrefs;
typedef struct _jc_java_lang_VMCompiler$refs	_jc_java_lang_VMCompiler$refs;
typedef struct _jc_java_lang_VMCompiler$nonrefs	_jc_java_lang_VMCompiler$nonrefs;
typedef struct _jc_java_lang_VMCompiler$object	_jc_java_lang_VMCompiler$object;

typedef const struct _jc_java_lang_VMCompiler$vmethods	_jc_java_lang_VMCompiler$vmethods;
typedef const struct _jc_java_lang_VMCompiler$vtable	_jc_java_lang_VMCompiler$vtable;
typedef const struct _jc_java_lang_VMCompiler$vtype	_jc_java_lang_VMCompiler$vtype;

// Constructors
extern void _jc_java_lang_VMCompiler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMCompiler$object *);

// Static methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_VMCompiler$method$command$9c4610a0259285ef(_jc_env *, struct _jc_java_lang_Object$object *);
extern jboolean _jc_java_lang_VMCompiler$method$compileClass$258fd65025401c03(_jc_env *, struct _jc_java_lang_Class$object *);
extern jboolean _jc_java_lang_VMCompiler$method$compileClasses$f9c43047d6e51ee8(_jc_env *, struct _jc_java_lang_String$object *);
extern void _jc_java_lang_VMCompiler$method$disable$76bb9c74f42e72e3(_jc_env *);
extern void _jc_java_lang_VMCompiler$method$enable$d5c88e4ee7026bca(_jc_env *);

// Virtual methods structure
struct _jc_java_lang_VMCompiler$vmethods {
};

// Vtable
struct _jc_java_lang_VMCompiler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMCompiler$vmethods	java_lang_VMCompiler;
};

// Vtype
struct _jc_java_lang_VMCompiler$vtype {
	_jc_type			type;
	_jc_java_lang_VMCompiler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMCompiler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMCompiler$refs {
    _jc_java_lang_VMCompiler$sub_refs	java_lang_VMCompiler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMCompiler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMCompiler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMCompiler$sub_nonrefs	java_lang_VMCompiler;
};

// Object instance structure
struct _jc_java_lang_VMCompiler$object {
	_jc_java_lang_VMCompiler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMCompiler$vtype	*vtype;
	_jc_java_lang_VMCompiler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMCompiler$vtype _jc_java_lang_VMCompiler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMCompiler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMCompiler$class_object;

#endif	/* _JC_java_lang_VMCompiler_H_ */

==> jc-1.4.6.tar.gz: java/lang/VMCompiler.h <==
// final class java.lang.VMCompiler

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 1ec1b2c5fdf4b5df java_lang_VMCompiler

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_java_lang_VMCompiler_H_
#define _JC_java_lang_VMCompiler_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_VMCompiler$sub_refs	_jc_java_lang_VMCompiler$sub_refs;
typedef struct _jc_java_lang_VMCompiler$sub_nonrefs	_jc_java_lang_VMCompiler$sub_nonrefs;
typedef struct _jc_java_lang_VMCompiler$refs	_jc_java_lang_VMCompiler$refs;
typedef struct _jc_java_lang_VMCompiler$nonrefs	_jc_java_lang_VMCompiler$nonrefs;
typedef struct _jc_java_lang_VMCompiler$object	_jc_java_lang_VMCompiler$object;

typedef const struct _jc_java_lang_VMCompiler$vmethods	_jc_java_lang_VMCompiler$vmethods;
typedef const struct _jc_java_lang_VMCompiler$vtable	_jc_java_lang_VMCompiler$vtable;
typedef const struct _jc_java_lang_VMCompiler$vtype	_jc_java_lang_VMCompiler$vtype;

// Constructors
extern void _jc_java_lang_VMCompiler$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_VMCompiler$object *) _JC_JCNI_ATTR;

// Static methods
extern struct _jc_java_lang_Object$object *_jc_java_lang_VMCompiler$method$command$9c4610a0259285ef(_jc_env *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_VMCompiler$method$compileClass$258fd65025401c03(_jc_env *, struct _jc_java_lang_Class$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_lang_VMCompiler$method$compileClasses$f9c43047d6e51ee8(_jc_env *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMCompiler$method$disable$76bb9c74f42e72e3(_jc_env *) _JC_JCNI_ATTR;
extern void _jc_java_lang_VMCompiler$method$enable$d5c88e4ee7026bca(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_VMCompiler$vmethods {
};

// Vtable
struct _jc_java_lang_VMCompiler$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_VMCompiler$vmethods	java_lang_VMCompiler;
};

// Vtype
struct _jc_java_lang_VMCompiler$vtype {
	_jc_type			type;
	_jc_java_lang_VMCompiler$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_VMCompiler$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_VMCompiler$refs {
    _jc_java_lang_VMCompiler$sub_refs	java_lang_VMCompiler;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_VMCompiler$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_VMCompiler$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_VMCompiler$sub_nonrefs	java_lang_VMCompiler;
};

// Object instance structure
struct _jc_java_lang_VMCompiler$object {
	_jc_java_lang_VMCompiler$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_VMCompiler$vtype	*vtype;
	_jc_java_lang_VMCompiler$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_VMCompiler$vtype _jc_java_lang_VMCompiler$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_VMCompiler, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_VMCompiler$class_object;

#endif	/* _JC_java_lang_VMCompiler_H_ */
